@@ -1,11 +1,12 @@
 #' Get the number of levels for each factor used in `xlevels`
 #'
-#' @param model a model object
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model object.
 #' @return a tibble with two columns: `"variable"` and `"var_nlevels"`
 #' @export
 #' @family model_helpers
 #' @examples
-#' lm(hp ~ mpg + factor(cyl), mtcars) %>%
+#' lm(hp ~ mpg + factor(cyl), mtcars) |>
 #'   model_get_nlevels()
 model_get_nlevels <- function(model) {
   UseMethod("model_get_nlevels")
@@ -14,10 +15,10 @@ model_get_nlevels <- function(model) {
 #' @export
 #' @rdname model_get_nlevels
 model_get_nlevels.default <- function(model) {
-  nlevels <- model_get_xlevels(model) %>% lapply(length)
+  nlevels <- model_get_xlevels(model) |> lapply(length)
   if (length(nlevels) == 0) {
     return(
-      dplyr::tibble(variable = NA_character_, var_nlevels = NA_integer_) %>%
+      dplyr::tibble(variable = NA_character_, var_nlevels = NA_integer_) |>
         dplyr::filter(FALSE) # empty tibble
     )
   }
