@@ -2,7 +2,8 @@
 #'
 #' This function does not cover `lavaan` models (`NULL` is returned).
 #'
-#' @param model a model object
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model object.
 #' @export
 #' @family model_helpers
 #' @examples
@@ -11,7 +12,7 @@
 #'   gtsummary::trial,
 #'   family = poisson
 #' )
-#' mod %>% model_get_offset()
+#' mod |> model_get_offset()
 model_get_offset <- function(model) {
   UseMethod("model_get_offset")
 }
@@ -20,8 +21,8 @@ model_get_offset <- function(model) {
 #' @rdname model_get_offset
 model_get_offset.default <- function(model) {
   tryCatch(
-    model %>%
-      model_get_model_frame() %>%
+    model |>
+      model_get_model_frame() |>
       stats::model.offset(),
     error = function(e) {
       NULL # nocov
