@@ -3,12 +3,13 @@
 #' Return the result of [stats::terms()] applied to the model
 #' or `NULL` if it is not possible to get terms from `model`.
 #'
-#' @param model a model object
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model object.
 #' @export
 #' @family model_helpers
 #' @seealso [stats::terms()]
 #' @examples
-#' lm(hp ~ mpg + factor(cyl), mtcars) %>%
+#' lm(hp ~ mpg + factor(cyl), mtcars) |>
 #'   model_get_terms()
 model_get_terms <- function(model) {
   UseMethod("model_get_terms")
@@ -28,9 +29,9 @@ model_get_terms.default <- function(model) {
 #' @export
 #' @rdname model_get_terms
 model_get_terms.brmsfit <- function(model) {
-  model$formula %>%
-    brms::brmsterms(resp_rhs_all = FALSE) %>%
-    purrr::pluck("allvars") %>%
+  model$formula |>
+    brms::brmsterms(resp_rhs_all = FALSE) |>
+    purrr::pluck("allvars") |>
     stats::terms()
 }
 
@@ -41,7 +42,7 @@ model_get_terms.brmsfit <- function(model) {
 #' taking into account all components ("cond" and "zi"). For a more
 #' restricted terms object, please refer to `glmmTMB::terms.glmmTMB()`.
 model_get_terms.glmmTMB <- function(model) {
-  model$modelInfo$allForm$combForm %>% stats::terms()
+  model$modelInfo$allForm$combForm |> stats::terms()
 }
 
 #' @export
@@ -55,3 +56,42 @@ model_get_terms.model_fit <- function(model) {
 model_get_terms.betareg <- function(model) {
   model_get_terms(model$terms$full)
 }
+
+#' @export
+#' @rdname model_get_terms
+model_get_terms.betareg <- function(model) {
+  model_get_terms(model$terms$full)
+}
+
+#' @export
+#' @rdname model_get_terms
+model_get_terms.cch <- function(model) {
+  stats::terms.formula(
+    model$call$formula |> stats::formula(),
+    data = model |> model_get_model_frame()
+  )
+}
+
+#' @export
+#' @rdname model_get_terms
+#' @details
+#' For `fixest` models, return a term object combining main variables and
+#' instrumental variables.
+#'
+model_get_terms.fixest <- function(model) {
+  fml <- model$fml
+  fiv <- model$iv_endo_fml
+
+  if (is.null(fiv)) {
+    f <- fml
+  } else {
+    f <-
+      paste(
+        deparse(fml),
+        "+",
+        deparse(fiv[[3]])
+      ) |>
+      stats::as.formula()
+  }
+  stats::terms(f)
+}
